@@ -33,7 +33,7 @@ import subprocess
 import argparse
 import io
 
-system_version = "2.4.5"  # This MUST MATCH the version specified in setup.py
+system_version = "2.4.9"  # This MUST MATCH the version specified in setup.py
 api_version = "0.0.3"
 
 IS_PY3 = sys.version_info.major == 3
@@ -80,6 +80,7 @@ is_serial_connecting = False
 octoprint_settings = None
 http = None
 last_request_response_code = None
+op_down_check = 0
 
 if not os.path.exists(temp_files_path):
     os.makedirs(temp_files_path)
@@ -143,7 +144,7 @@ rpi_id_loc = os.path.join(dir_path, "simplyprint_rpi_id.txt")
 def set_rpi_id(new_id):
     global rpi_id_loc
 
-    with open(rpi_id_loc, "w") as thefile:
+    with io.open(rpi_id_loc, "w") as thefile:
         thefile.write(new_id)
 
 
@@ -234,7 +235,7 @@ def get_octoprint_api_key():
     global hasmodified, config
 
     try:
-        with open("/home/pi/.octoprint/config.yaml", 'r') as stream:
+        with io.open("/home/pi/.octoprint/config.yaml", 'r') as stream:
             try:
                 the_config = yaml.safe_load(stream)
                 the_key = the_config["api"]["key"]
@@ -286,8 +287,12 @@ def set_config():
     if hasmodified:
         log("Settings were modified. Updating settings.ini file...")
 
-        with open(settings_location, "w") as configfile:
-            config.write(configfile)
+        if IS_PY3:
+            with io.open(settings_location, "w", encoding="utf-8") as configfile:
+                config.write(configfile)
+        else:
+            with open(settings_location, "w") as configfile:
+                config.write(configfile)
 
         if str(config.get("info", "is_set_up")) == "True":
             is_set_up = True
@@ -338,7 +343,7 @@ def sub_start_script(script):
 
 
 def get_request(url, no_json=False, is_api_request=False, get_response_code=False, is_octoprint_request=False):
-    global http, last_request_response_code
+    global http, last_request_response_code, op_down_check
 
     url = url.replace(" ", "%20")
     response_code = None
@@ -386,19 +391,25 @@ def get_request(url, no_json=False, is_api_request=False, get_response_code=Fals
             get_octoprint_api_key()
             website_ping_update("&octoprint_api_key=" + octoprint_apikey())
 
+        down_to_set = ""
+
         if "503" in str(e) and is_api_request:
             if not config.getboolean("info", "octoprint_down"):
+                op_down_check = 0
                 down_to_set = "True"
                 log("OctoPrint is down (503: Service Unavailable) - waiting to make sure it's really down, "
                     "then restarting")
                 website_ping_update("&octoprint_status=Shutdown")
             else:
-                down_to_set = "False"
-                log("OctoPrint is STILL down - restarting the OctoPrint service")
-                os.system("sudo service octoprint restart")
+                op_down_check += 1
+                if op_down_check > 6:
+                    down_to_set = "False"
+                    log("OctoPrint is STILL down - restarting the OctoPrint service")
+                    os.system("sudo service octoprint restart")
 
-            set_config_key("info", "octoprint_down", down_to_set)
-            set_config()
+            if down_to_set != "":
+                set_config_key("info", "octoprint_down", down_to_set)
+                set_config()
 
         return False
 
@@ -822,7 +833,7 @@ def get_post_image(picture_id=None, do_log=True):
                     log("Taking picture...")
                 the_download = download_file(the_url, new_name)
                 if the_download[0]:
-                    with open(new_name, "rb") as f:
+                    with io.open(new_name, "rb") as f:
                         if do_log:
                             log("Uploading picture...")
                         r = requests.post(upl_url, files={"the_file": f})
@@ -1009,5 +1020,9 @@ def webrequest_pid(make_new=True):
                 pass
 
     if make_new:
-        with open(webrequest_pid_file, "wt", encoding="utf-8") as file:
-            file.write(str(os.getpid()))
+        if IS_PY3:
+            with io.open(webrequest_pid_file, "wt", encoding="utf-8") as file:
+                file.write(str(os.getpid()))
+        else:
+            with open(webrequest_pid_file, "wt") as file:
+                file.write(str(os.getpid()))
