@@ -519,13 +519,13 @@ def do_the_request(num):
                                 log("Installing OctoPrint plugin " + action["name"] + "!")
                                 installed_plugins.append(action["key"])
 
-                                with open(plugins_txt, "a") as myfile:
+                                with io.open(plugins_txt, "a") as myfile:
                                     myfile.write(action["name"] + "\n")
 
                                 # "Notify" plugin of plugins installed through SimplyPrint!
                                 sp_plugins = []
                                 if os.path.isfile(plugins_txt):
-                                    with open(plugins_txt) as f:
+                                    with io.open(plugins_txt) as f:
                                         for line in f:
                                             if len(line) and (line.strip() not in sp_plugins):
                                                 sp_plugins.append(line.strip())
@@ -540,15 +540,20 @@ def do_the_request(num):
                                 })
 
                                 # Install through pip, and restart OctoPrint
-                                command_uninstall = [sys.executable, "-m", "pip", "uninstall", "-y", + action["pip_name"]]
-                                command_install = [sys.executable, "-m", "pip", "install", action["install_url"]]
-                                process = subprocess.Popen(command_uninstall, stdout=subprocess.PIPE, stderr=subprocess.PIPE)
+                                print(str(action))
+
+                                pipname = action["pip_name"]
+
+                                command_uninstall = [sys.executable, "-m", "pip", "uninstall", "-y", pipname]
+                                process = subprocess.Popen(command_uninstall, stdout=subprocess.PIPE,
+                                                           stderr=subprocess.PIPE)
                                 stdout, stderr = process.communicate()
                                 log("Uninstall command, stdout" + str(stdout.decode("utf-8", errors="replace")))
                                 log("Uninstall command, stderr" + str(stderr.decode("utf-8", errors="replace")))
-                                
-                                command_install = [sys.executable, "-m", "pip", "install", action["install_url"]]
-                                process2 = subprocess.Popen(command_install, stdout=subprocess.PIPE, stderr=subprocess.PIPE)
+
+                                command_install = [sys.executable, "-m", "pip", "install", str(action["install_url"])]
+                                process2 = subprocess.Popen(command_install, stdout=subprocess.PIPE,
+                                                            stderr=subprocess.PIPE)
                                 stdout, stderr = process2.communicate()
                                 log("Uninstall command, stdout" + str(stdout.decode("utf-8", errors="replace")))
                                 log("Uninstall command, stderr" + str(stderr.decode("utf-8", errors="replace")))
@@ -561,7 +566,7 @@ def do_the_request(num):
                                     # Get current plugins
                                     log("Uninstalling OctoPrint plugin; " + action["name"])
 
-                                    with open(plugins_txt, "r") as f:
+                                    with io.open(plugins_txt, "r") as f:
                                         for line in f:
                                             stripped_line = line.strip()
                                             if len(line) and stripped_line != action["name"].strip():
@@ -578,7 +583,7 @@ def do_the_request(num):
                                     })
 
                                     # Set new list not containing the about-to-be-deleted one
-                                    with open(plugins_txt, "w") as f:
+                                    with io.open(plugins_txt, "w") as f:
                                         for line in sp_plugins:
                                             f.write(line + "\n")
 
